# coding: utf-8

"""
    shado-python-client

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from shado_client.models.object_id import ObjectID  # noqa: F401,E501


class PluginInstance(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_at': 'datetime',
        'description': 'str',
        'error': 'object',
        'finished_at': 'datetime',
        'name': 'str',
        'parameters': 'object',
        'progress': 'float',
        'results': 'object',
        'started_at': 'datetime',
        'status': 'str',
        'type': 'str',
        'id': 'ObjectID',
        'owner_id': 'ObjectID',
        'plugin_id': 'ObjectID'
    }

    attribute_map = {
        'created_at': 'createdAt',
        'description': 'description',
        'error': 'error',
        'finished_at': 'finishedAt',
        'name': 'name',
        'parameters': 'parameters',
        'progress': 'progress',
        'results': 'results',
        'started_at': 'startedAt',
        'status': 'status',
        'type': 'type',
        'id': 'id',
        'owner_id': 'ownerId',
        'plugin_id': 'pluginId'
    }

    def __init__(self, created_at=None, description=None, error=None, finished_at=None, name=None, parameters=None, progress=0.0, results=None, started_at=None, status='queued', type='cpu', id=None, owner_id=None, plugin_id=None):  # noqa: E501
        """PluginInstance - a model defined in Swagger"""  # noqa: E501

        self._created_at = None
        self._description = None
        self._error = None
        self._finished_at = None
        self._name = None
        self._parameters = None
        self._progress = None
        self._results = None
        self._started_at = None
        self._status = None
        self._type = None
        self._id = None
        self._owner_id = None
        self._plugin_id = None
        self.discriminator = None

        if created_at is not None:
            self.created_at = created_at
        if description is not None:
            self.description = description
        if error is not None:
            self.error = error
        if finished_at is not None:
            self.finished_at = finished_at
        if name is not None:
            self.name = name
        if parameters is not None:
            self.parameters = parameters
        if progress is not None:
            self.progress = progress
        if results is not None:
            self.results = results
        if started_at is not None:
            self.started_at = started_at
        if status is not None:
            self.status = status
        if type is not None:
            self.type = type
        if id is not None:
            self.id = id
        if owner_id is not None:
            self.owner_id = owner_id
        if plugin_id is not None:
            self.plugin_id = plugin_id

    @property
    def created_at(self):
        """Gets the created_at of this PluginInstance.  # noqa: E501


        :return: The created_at of this PluginInstance.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this PluginInstance.


        :param created_at: The created_at of this PluginInstance.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def description(self):
        """Gets the description of this PluginInstance.  # noqa: E501


        :return: The description of this PluginInstance.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PluginInstance.


        :param description: The description of this PluginInstance.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def error(self):
        """Gets the error of this PluginInstance.  # noqa: E501


        :return: The error of this PluginInstance.  # noqa: E501
        :rtype: object
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this PluginInstance.


        :param error: The error of this PluginInstance.  # noqa: E501
        :type: object
        """

        self._error = error

    @property
    def finished_at(self):
        """Gets the finished_at of this PluginInstance.  # noqa: E501


        :return: The finished_at of this PluginInstance.  # noqa: E501
        :rtype: datetime
        """
        return self._finished_at

    @finished_at.setter
    def finished_at(self, finished_at):
        """Sets the finished_at of this PluginInstance.


        :param finished_at: The finished_at of this PluginInstance.  # noqa: E501
        :type: datetime
        """

        self._finished_at = finished_at

    @property
    def name(self):
        """Gets the name of this PluginInstance.  # noqa: E501


        :return: The name of this PluginInstance.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PluginInstance.


        :param name: The name of this PluginInstance.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def parameters(self):
        """Gets the parameters of this PluginInstance.  # noqa: E501


        :return: The parameters of this PluginInstance.  # noqa: E501
        :rtype: object
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this PluginInstance.


        :param parameters: The parameters of this PluginInstance.  # noqa: E501
        :type: object
        """

        self._parameters = parameters

    @property
    def progress(self):
        """Gets the progress of this PluginInstance.  # noqa: E501


        :return: The progress of this PluginInstance.  # noqa: E501
        :rtype: float
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        """Sets the progress of this PluginInstance.


        :param progress: The progress of this PluginInstance.  # noqa: E501
        :type: float
        """

        self._progress = progress

    @property
    def results(self):
        """Gets the results of this PluginInstance.  # noqa: E501


        :return: The results of this PluginInstance.  # noqa: E501
        :rtype: object
        """
        return self._results

    @results.setter
    def results(self, results):
        """Sets the results of this PluginInstance.


        :param results: The results of this PluginInstance.  # noqa: E501
        :type: object
        """

        self._results = results

    @property
    def started_at(self):
        """Gets the started_at of this PluginInstance.  # noqa: E501


        :return: The started_at of this PluginInstance.  # noqa: E501
        :rtype: datetime
        """
        return self._started_at

    @started_at.setter
    def started_at(self, started_at):
        """Sets the started_at of this PluginInstance.


        :param started_at: The started_at of this PluginInstance.  # noqa: E501
        :type: datetime
        """

        self._started_at = started_at

    @property
    def status(self):
        """Gets the status of this PluginInstance.  # noqa: E501


        :return: The status of this PluginInstance.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this PluginInstance.


        :param status: The status of this PluginInstance.  # noqa: E501
        :type: str
        """
        allowed_values = ["queued", "started", "finished", "failed"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def type(self):
        """Gets the type of this PluginInstance.  # noqa: E501


        :return: The type of this PluginInstance.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this PluginInstance.


        :param type: The type of this PluginInstance.  # noqa: E501
        :type: str
        """
        allowed_values = ["cpu", "gpu"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def id(self):
        """Gets the id of this PluginInstance.  # noqa: E501


        :return: The id of this PluginInstance.  # noqa: E501
        :rtype: ObjectID
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PluginInstance.


        :param id: The id of this PluginInstance.  # noqa: E501
        :type: ObjectID
        """

        self._id = id

    @property
    def owner_id(self):
        """Gets the owner_id of this PluginInstance.  # noqa: E501


        :return: The owner_id of this PluginInstance.  # noqa: E501
        :rtype: ObjectID
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this PluginInstance.


        :param owner_id: The owner_id of this PluginInstance.  # noqa: E501
        :type: ObjectID
        """

        self._owner_id = owner_id

    @property
    def plugin_id(self):
        """Gets the plugin_id of this PluginInstance.  # noqa: E501


        :return: The plugin_id of this PluginInstance.  # noqa: E501
        :rtype: ObjectID
        """
        return self._plugin_id

    @plugin_id.setter
    def plugin_id(self, plugin_id):
        """Sets the plugin_id of this PluginInstance.


        :param plugin_id: The plugin_id of this PluginInstance.  # noqa: E501
        :type: ObjectID
        """

        self._plugin_id = plugin_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PluginInstance):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from shado_client.api.account_api import AccountApi
from shado_client.api.group_api import GroupApi
from shado_client.api.invitation_api import InvitationApi
from shado_client.api.item_api import ItemApi
from shado_client.api.membership_api import MembershipApi
from shado_client.api.plugin_api import PluginApi
from shado_client.api.plugin_instance_api import PluginInstanceApi
from shado_client.api.result_api import ResultApi
from shado_client.api.sharing_api import SharingApi



# coding: utf-8

"""
    shado-python-client

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from shado_client.api_client import ApiClient


class AccountApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def account_apply_reset(self, access_token_id, password, new_password, **kwargs):  # noqa: E501
        """Execute the password reset for a user with email.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_apply_reset(access_token_id, password, new_password, async=True)
        >>> result = thread.get()

        :param async bool
        :param str access_token_id: (required)
        :param str password: (required)
        :param str new_password: (required)
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.account_apply_reset_with_http_info(access_token_id, password, new_password, **kwargs)  # noqa: E501
        else:
            (data) = self.account_apply_reset_with_http_info(access_token_id, password, new_password, **kwargs)  # noqa: E501
            return data

    def account_apply_reset_with_http_info(self, access_token_id, password, new_password, **kwargs):  # noqa: E501
        """Execute the password reset for a user with email.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_apply_reset_with_http_info(access_token_id, password, new_password, async=True)
        >>> result = thread.get()

        :param async bool
        :param str access_token_id: (required)
        :param str password: (required)
        :param str new_password: (required)
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['access_token_id', 'password', 'new_password']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method account_apply_reset" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'access_token_id' is set
        if ('access_token_id' not in params or
                params['access_token_id'] is None):
            raise ValueError("Missing the required parameter `access_token_id` when calling `account_apply_reset`")  # noqa: E501
        # verify the required parameter 'password' is set
        if ('password' not in params or
                params['password'] is None):
            raise ValueError("Missing the required parameter `password` when calling `account_apply_reset`")  # noqa: E501
        # verify the required parameter 'new_password' is set
        if ('new_password' not in params or
                params['new_password'] is None):
            raise ValueError("Missing the required parameter `new_password` when calling `account_apply_reset`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'access_token_id' in params:
            form_params.append(('accessTokenId', params['access_token_id']))  # noqa: E501
        if 'password' in params:
            form_params.append(('password', params['password']))  # noqa: E501
        if 'new_password' in params:
            form_params.append(('newPassword', params['new_password']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Accounts/reset', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2001',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def account_change_password_post_accounts_change_password(self, old_password, new_password, **kwargs):  # noqa: E501
        """Change a user&#39;s password.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_change_password_post_accounts_change_password(old_password, new_password, async=True)
        >>> result = thread.get()

        :param async bool
        :param str old_password: (required)
        :param str new_password: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.account_change_password_post_accounts_change_password_with_http_info(old_password, new_password, **kwargs)  # noqa: E501
        else:
            (data) = self.account_change_password_post_accounts_change_password_with_http_info(old_password, new_password, **kwargs)  # noqa: E501
            return data

    def account_change_password_post_accounts_change_password_with_http_info(self, old_password, new_password, **kwargs):  # noqa: E501
        """Change a user&#39;s password.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_change_password_post_accounts_change_password_with_http_info(old_password, new_password, async=True)
        >>> result = thread.get()

        :param async bool
        :param str old_password: (required)
        :param str new_password: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['old_password', 'new_password']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method account_change_password_post_accounts_change_password" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'old_password' is set
        if ('old_password' not in params or
                params['old_password'] is None):
            raise ValueError("Missing the required parameter `old_password` when calling `account_change_password_post_accounts_change_password`")  # noqa: E501
        # verify the required parameter 'new_password' is set
        if ('new_password' not in params or
                params['new_password'] is None):
            raise ValueError("Missing the required parameter `new_password` when calling `account_change_password_post_accounts_change_password`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'old_password' in params:
            form_params.append(('oldPassword', params['old_password']))  # noqa: E501
        if 'new_password' in params:
            form_params.append(('newPassword', params['new_password']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Accounts/change-password', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def account_change_password_put_accountsid_change_password(self, id, password, password2, **kwargs):  # noqa: E501
        """Execute the password change for the given user.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_change_password_put_accountsid_change_password(id, password, password2, async=True)
        >>> result = thread.get()

        :param async bool
        :param str id: (required)
        :param str password: (required)
        :param str password2: (required)
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.account_change_password_put_accountsid_change_password_with_http_info(id, password, password2, **kwargs)  # noqa: E501
        else:
            (data) = self.account_change_password_put_accountsid_change_password_with_http_info(id, password, password2, **kwargs)  # noqa: E501
            return data

    def account_change_password_put_accountsid_change_password_with_http_info(self, id, password, password2, **kwargs):  # noqa: E501
        """Execute the password change for the given user.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_change_password_put_accountsid_change_password_with_http_info(id, password, password2, async=True)
        >>> result = thread.get()

        :param async bool
        :param str id: (required)
        :param str password: (required)
        :param str password2: (required)
        :return: InlineResponse2001
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'password', 'password2']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method account_change_password_put_accountsid_change_password" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `account_change_password_put_accountsid_change_password`")  # noqa: E501
        # verify the required parameter 'password' is set
        if ('password' not in params or
                params['password'] is None):
            raise ValueError("Missing the required parameter `password` when calling `account_change_password_put_accountsid_change_password`")  # noqa: E501
        # verify the required parameter 'password2' is set
        if ('password2' not in params or
                params['password2'] is None):
            raise ValueError("Missing the required parameter `password2` when calling `account_change_password_put_accountsid_change_password`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'password' in params:
            form_params.append(('password', params['password']))  # noqa: E501
        if 'password2' in params:
            form_params.append(('password2', params['password2']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Accounts/{id}/changePassword', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse2001',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def account_confirm(self, uid, token, **kwargs):  # noqa: E501
        """Confirm a user registration with identity verification token.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_confirm(uid, token, async=True)
        >>> result = thread.get()

        :param async bool
        :param str uid: (required)
        :param str token: (required)
        :param str redirect:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.account_confirm_with_http_info(uid, token, **kwargs)  # noqa: E501
        else:
            (data) = self.account_confirm_with_http_info(uid, token, **kwargs)  # noqa: E501
            return data

    def account_confirm_with_http_info(self, uid, token, **kwargs):  # noqa: E501
        """Confirm a user registration with identity verification token.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_confirm_with_http_info(uid, token, async=True)
        >>> result = thread.get()

        :param async bool
        :param str uid: (required)
        :param str token: (required)
        :param str redirect:
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uid', 'token', 'redirect']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method account_confirm" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uid' is set
        if ('uid' not in params or
                params['uid'] is None):
            raise ValueError("Missing the required parameter `uid` when calling `account_confirm`")  # noqa: E501
        # verify the required parameter 'token' is set
        if ('token' not in params or
                params['token'] is None):
            raise ValueError("Missing the required parameter `token` when calling `account_confirm`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'uid' in params:
            query_params.append(('uid', params['uid']))  # noqa: E501
        if 'token' in params:
            query_params.append(('token', params['token']))  # noqa: E501
        if 'redirect' in params:
            query_params.append(('redirect', params['redirect']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Accounts/confirm', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def account_create(self, **kwargs):  # noqa: E501
        """Create a new instance of the model and persist it into the data source.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_create(async=True)
        >>> result = thread.get()

        :param async bool
        :param Account data: Model instance data
        :return: Account
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.account_create_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.account_create_with_http_info(**kwargs)  # noqa: E501
            return data

    def account_create_with_http_info(self, **kwargs):  # noqa: E501
        """Create a new instance of the model and persist it into the data source.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_create_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :param Account data: Model instance data
        :return: Account
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['data']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method account_create" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'data' in params:
            body_params = params['data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Accounts', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Account',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def account_create_change_stream_get_accounts_change_stream(self, **kwargs):  # noqa: E501
        """Create a change stream.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_create_change_stream_get_accounts_change_stream(async=True)
        >>> result = thread.get()

        :param async bool
        :param str options:
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.account_create_change_stream_get_accounts_change_stream_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.account_create_change_stream_get_accounts_change_stream_with_http_info(**kwargs)  # noqa: E501
            return data

    def account_create_change_stream_get_accounts_change_stream_with_http_info(self, **kwargs):  # noqa: E501
        """Create a change stream.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_create_change_stream_get_accounts_change_stream_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :param str options:
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['options']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method account_create_change_stream_get_accounts_change_stream" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'options' in params:
            query_params.append(('options', params['options']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Accounts/change-stream', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='file',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def account_create_change_stream_post_accounts_change_stream(self, **kwargs):  # noqa: E501
        """Create a change stream.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_create_change_stream_post_accounts_change_stream(async=True)
        >>> result = thread.get()

        :param async bool
        :param str options:
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.account_create_change_stream_post_accounts_change_stream_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.account_create_change_stream_post_accounts_change_stream_with_http_info(**kwargs)  # noqa: E501
            return data

    def account_create_change_stream_post_accounts_change_stream_with_http_info(self, **kwargs):  # noqa: E501
        """Create a change stream.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_create_change_stream_post_accounts_change_stream_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :param str options:
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['options']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method account_create_change_stream_post_accounts_change_stream" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'options' in params:
            form_params.append(('options', params['options']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Accounts/change-stream', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='file',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def account_delete_by_id(self, id, **kwargs):  # noqa: E501
        """Delete a model instance by {{id}} from the data source.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_delete_by_id(id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str id: Model id (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.account_delete_by_id_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.account_delete_by_id_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def account_delete_by_id_with_http_info(self, id, **kwargs):  # noqa: E501
        """Delete a model instance by {{id}} from the data source.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_delete_by_id_with_http_info(id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str id: Model id (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method account_delete_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `account_delete_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Accounts/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def account_find(self, **kwargs):  # noqa: E501
        """Find all instances of the model matched by filter from the data source.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_find(async=True)
        >>> result = thread.get()

        :param async bool
        :param str filter: Filter defining fields, where, include, order, offset, and limit - must be a JSON-encoded string ({\"something\":\"value\"})
        :return: list[Account]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.account_find_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.account_find_with_http_info(**kwargs)  # noqa: E501
            return data

    def account_find_with_http_info(self, **kwargs):  # noqa: E501
        """Find all instances of the model matched by filter from the data source.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_find_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :param str filter: Filter defining fields, where, include, order, offset, and limit - must be a JSON-encoded string ({\"something\":\"value\"})
        :return: list[Account]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['filter']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method account_find" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter' in params:
            query_params.append(('filter', params['filter']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Accounts', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Account]',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def account_find_by_id(self, id, **kwargs):  # noqa: E501
        """Find a model instance by {{id}} from the data source.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_find_by_id(id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str id: Model id (required)
        :param str filter: Filter defining fields and include - must be a JSON-encoded string ({\"something\":\"value\"})
        :return: Account
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.account_find_by_id_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.account_find_by_id_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def account_find_by_id_with_http_info(self, id, **kwargs):  # noqa: E501
        """Find a model instance by {{id}} from the data source.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_find_by_id_with_http_info(id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str id: Model id (required)
        :param str filter: Filter defining fields and include - must be a JSON-encoded string ({\"something\":\"value\"})
        :return: Account
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'filter']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method account_find_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `account_find_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'filter' in params:
            query_params.append(('filter', params['filter']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Accounts/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Account',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def account_login(self, credentials, **kwargs):  # noqa: E501
        """Login a user with username/email and password.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_login(credentials, async=True)
        >>> result = thread.get()

        :param async bool
        :param object credentials: (required)
        :param str include: Related objects to include in the response. See the description of return value for more details.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.account_login_with_http_info(credentials, **kwargs)  # noqa: E501
        else:
            (data) = self.account_login_with_http_info(credentials, **kwargs)  # noqa: E501
            return data

    def account_login_with_http_info(self, credentials, **kwargs):  # noqa: E501
        """Login a user with username/email and password.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_login_with_http_info(credentials, async=True)
        >>> result = thread.get()

        :param async bool
        :param object credentials: (required)
        :param str include: Related objects to include in the response. See the description of return value for more details.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['credentials', 'include']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method account_login" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'credentials' is set
        if ('credentials' not in params or
                params['credentials'] is None):
            raise ValueError("Missing the required parameter `credentials` when calling `account_login`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'include' in params:
            query_params.append(('include', params['include']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'credentials' in params:
            body_params = params['credentials']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Accounts/login', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def account_logout(self, **kwargs):  # noqa: E501
        """Logout a user with access token.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_logout(async=True)
        >>> result = thread.get()

        :param async bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.account_logout_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.account_logout_with_http_info(**kwargs)  # noqa: E501
            return data

    def account_logout_with_http_info(self, **kwargs):  # noqa: E501
        """Logout a user with access token.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_logout_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method account_logout" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Accounts/logout', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def account_replace_by_id_post_accountsid_replace(self, id, **kwargs):  # noqa: E501
        """Replace attributes for a model instance and persist it into the data source.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_replace_by_id_post_accountsid_replace(id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str id: Model id (required)
        :param Account data: Model instance data
        :return: Account
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.account_replace_by_id_post_accountsid_replace_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.account_replace_by_id_post_accountsid_replace_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def account_replace_by_id_post_accountsid_replace_with_http_info(self, id, **kwargs):  # noqa: E501
        """Replace attributes for a model instance and persist it into the data source.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_replace_by_id_post_accountsid_replace_with_http_info(id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str id: Model id (required)
        :param Account data: Model instance data
        :return: Account
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'data']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method account_replace_by_id_post_accountsid_replace" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `account_replace_by_id_post_accountsid_replace`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'data' in params:
            body_params = params['data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Accounts/{id}/replace', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Account',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def account_replace_by_id_put_accountsid(self, id, **kwargs):  # noqa: E501
        """Replace attributes for a model instance and persist it into the data source.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_replace_by_id_put_accountsid(id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str id: Model id (required)
        :param Account data: Model instance data
        :return: Account
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.account_replace_by_id_put_accountsid_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.account_replace_by_id_put_accountsid_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def account_replace_by_id_put_accountsid_with_http_info(self, id, **kwargs):  # noqa: E501
        """Replace attributes for a model instance and persist it into the data source.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_replace_by_id_put_accountsid_with_http_info(id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str id: Model id (required)
        :param Account data: Model instance data
        :return: Account
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'data']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method account_replace_by_id_put_accountsid" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `account_replace_by_id_put_accountsid`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'data' in params:
            body_params = params['data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Accounts/{id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Account',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def account_reset_password(self, options, **kwargs):  # noqa: E501
        """Reset password for a user with email.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_reset_password(options, async=True)
        >>> result = thread.get()

        :param async bool
        :param object options: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.account_reset_password_with_http_info(options, **kwargs)  # noqa: E501
        else:
            (data) = self.account_reset_password_with_http_info(options, **kwargs)  # noqa: E501
            return data

    def account_reset_password_with_http_info(self, options, **kwargs):  # noqa: E501
        """Reset password for a user with email.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_reset_password_with_http_info(options, async=True)
        >>> result = thread.get()

        :param async bool
        :param object options: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['options']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method account_reset_password" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'options' is set
        if ('options' not in params or
                params['options'] is None):
            raise ValueError("Missing the required parameter `options` when calling `account_reset_password`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'options' in params:
            body_params = params['options']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Accounts/reset', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def account_set_password(self, new_password, **kwargs):  # noqa: E501
        """Reset user&#39;s password via a password-reset token.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_set_password(new_password, async=True)
        >>> result = thread.get()

        :param async bool
        :param str new_password: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.account_set_password_with_http_info(new_password, **kwargs)  # noqa: E501
        else:
            (data) = self.account_set_password_with_http_info(new_password, **kwargs)  # noqa: E501
            return data

    def account_set_password_with_http_info(self, new_password, **kwargs):  # noqa: E501
        """Reset user&#39;s password via a password-reset token.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_set_password_with_http_info(new_password, async=True)
        >>> result = thread.get()

        :param async bool
        :param str new_password: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['new_password']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method account_set_password" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'new_password' is set
        if ('new_password' not in params or
                params['new_password'] is None):
            raise ValueError("Missing the required parameter `new_password` when calling `account_set_password`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'new_password' in params:
            form_params.append(('newPassword', params['new_password']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Accounts/reset-password', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def account_update_all(self, **kwargs):  # noqa: E501
        """Update instances of the model matched by {{where}} from the data source.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_update_all(async=True)
        >>> result = thread.get()

        :param async bool
        :param str where: Criteria to match model instances
        :param Account data: An object of model property name/value pairs
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.account_update_all_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.account_update_all_with_http_info(**kwargs)  # noqa: E501
            return data

    def account_update_all_with_http_info(self, **kwargs):  # noqa: E501
        """Update instances of the model matched by {{where}} from the data source.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.account_update_all_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :param str where: Criteria to match model instances
        :param Account data: An object of model property name/value pairs
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['where', 'data']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method account_update_all" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'where' in params:
            query_params.append(('where', params['where']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'data' in params:
            body_params = params['data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/Accounts/update', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

# flake8: noqa
"""
    shado-python-client

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from shado_client.models.account import Account
from shado_client.models.group import Group
from shado_client.models.inline_response_200 import InlineResponse200
from shado_client.models.inline_response_200_1 import InlineResponse2001
from shado_client.models.inline_response_200_2 import InlineResponse2002
from shado_client.models.inline_response_200_3 import InlineResponse2003
from shado_client.models.invitation import Invitation
from shado_client.models.item import Item
from shado_client.models.membership import Membership
from shado_client.models.object_id import ObjectID
from shado_client.models.plugin import Plugin
from shado_client.models.plugin_instance import PluginInstance
from shado_client.models.result import Result
from shado_client.models.sharing import Sharing
from shado_client.models.x_any import XAny



# coding: utf-8

"""
    shado-python-client

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from shado_client.models.object_id import ObjectID  # noqa: F401,E501
from shado_client.models.x_any import XAny  # noqa: F401,E501


class Result(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_at': 'datetime',
        'creator': 'list[XAny]',
        'description': 'str',
        'external_url': 'str',
        'filename': 'str',
        'format': 'str',
        'metadata': 'object',
        'mime': 'str',
        'preview': 'str',
        'resource_created_at': 'datetime',
        'size': 'float',
        'subject': 'list[XAny]',
        'title': 'str',
        'thumbnail': 'str',
        'type': 'str',
        'updated_at': 'datetime',
        'id': 'ObjectID',
        'owner_id': 'ObjectID'
    }

    attribute_map = {
        'created_at': 'createdAt',
        'creator': 'creator',
        'description': 'description',
        'external_url': 'external_url',
        'filename': 'filename',
        'format': 'format',
        'metadata': 'metadata',
        'mime': 'mime',
        'preview': 'preview',
        'resource_created_at': 'resourceCreatedAt',
        'size': 'size',
        'subject': 'subject',
        'title': 'title',
        'thumbnail': 'thumbnail',
        'type': 'type',
        'updated_at': 'updatedAt',
        'id': 'id',
        'owner_id': 'ownerId'
    }

    def __init__(self, created_at=None, creator=None, description='', external_url=None, filename=None, format=None, metadata=None, mime=None, preview=None, resource_created_at=None, size=0.0, subject=None, title=None, thumbnail=None, type='binary', updated_at=None, id=None, owner_id=None):  # noqa: E501
        """Result - a model defined in Swagger"""  # noqa: E501

        self._created_at = None
        self._creator = None
        self._description = None
        self._external_url = None
        self._filename = None
        self._format = None
        self._metadata = None
        self._mime = None
        self._preview = None
        self._resource_created_at = None
        self._size = None
        self._subject = None
        self._title = None
        self._thumbnail = None
        self._type = None
        self._updated_at = None
        self._id = None
        self._owner_id = None
        self.discriminator = None

        if created_at is not None:
            self.created_at = created_at
        if creator is not None:
            self.creator = creator
        if description is not None:
            self.description = description
        if external_url is not None:
            self.external_url = external_url
        if filename is not None:
            self.filename = filename
        if format is not None:
            self.format = format
        if metadata is not None:
            self.metadata = metadata
        if mime is not None:
            self.mime = mime
        if preview is not None:
            self.preview = preview
        if resource_created_at is not None:
            self.resource_created_at = resource_created_at
        if size is not None:
            self.size = size
        if subject is not None:
            self.subject = subject
        if title is not None:
            self.title = title
        if thumbnail is not None:
            self.thumbnail = thumbnail
        if type is not None:
            self.type = type
        if updated_at is not None:
            self.updated_at = updated_at
        if id is not None:
            self.id = id
        if owner_id is not None:
            self.owner_id = owner_id

    @property
    def created_at(self):
        """Gets the created_at of this Result.  # noqa: E501


        :return: The created_at of this Result.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Result.


        :param created_at: The created_at of this Result.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def creator(self):
        """Gets the creator of this Result.  # noqa: E501


        :return: The creator of this Result.  # noqa: E501
        :rtype: list[XAny]
        """
        return self._creator

    @creator.setter
    def creator(self, creator):
        """Sets the creator of this Result.


        :param creator: The creator of this Result.  # noqa: E501
        :type: list[XAny]
        """

        self._creator = creator

    @property
    def description(self):
        """Gets the description of this Result.  # noqa: E501


        :return: The description of this Result.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Result.


        :param description: The description of this Result.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def external_url(self):
        """Gets the external_url of this Result.  # noqa: E501


        :return: The external_url of this Result.  # noqa: E501
        :rtype: str
        """
        return self._external_url

    @external_url.setter
    def external_url(self, external_url):
        """Sets the external_url of this Result.


        :param external_url: The external_url of this Result.  # noqa: E501
        :type: str
        """

        self._external_url = external_url

    @property
    def filename(self):
        """Gets the filename of this Result.  # noqa: E501


        :return: The filename of this Result.  # noqa: E501
        :rtype: str
        """
        return self._filename

    @filename.setter
    def filename(self, filename):
        """Sets the filename of this Result.


        :param filename: The filename of this Result.  # noqa: E501
        :type: str
        """

        self._filename = filename

    @property
    def format(self):
        """Gets the format of this Result.  # noqa: E501


        :return: The format of this Result.  # noqa: E501
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this Result.


        :param format: The format of this Result.  # noqa: E501
        :type: str
        """

        self._format = format

    @property
    def metadata(self):
        """Gets the metadata of this Result.  # noqa: E501


        :return: The metadata of this Result.  # noqa: E501
        :rtype: object
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this Result.


        :param metadata: The metadata of this Result.  # noqa: E501
        :type: object
        """

        self._metadata = metadata

    @property
    def mime(self):
        """Gets the mime of this Result.  # noqa: E501


        :return: The mime of this Result.  # noqa: E501
        :rtype: str
        """
        return self._mime

    @mime.setter
    def mime(self, mime):
        """Sets the mime of this Result.


        :param mime: The mime of this Result.  # noqa: E501
        :type: str
        """

        self._mime = mime

    @property
    def preview(self):
        """Gets the preview of this Result.  # noqa: E501


        :return: The preview of this Result.  # noqa: E501
        :rtype: str
        """
        return self._preview

    @preview.setter
    def preview(self, preview):
        """Sets the preview of this Result.


        :param preview: The preview of this Result.  # noqa: E501
        :type: str
        """

        self._preview = preview

    @property
    def resource_created_at(self):
        """Gets the resource_created_at of this Result.  # noqa: E501


        :return: The resource_created_at of this Result.  # noqa: E501
        :rtype: datetime
        """
        return self._resource_created_at

    @resource_created_at.setter
    def resource_created_at(self, resource_created_at):
        """Sets the resource_created_at of this Result.


        :param resource_created_at: The resource_created_at of this Result.  # noqa: E501
        :type: datetime
        """

        self._resource_created_at = resource_created_at

    @property
    def size(self):
        """Gets the size of this Result.  # noqa: E501


        :return: The size of this Result.  # noqa: E501
        :rtype: float
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this Result.


        :param size: The size of this Result.  # noqa: E501
        :type: float
        """

        self._size = size

    @property
    def subject(self):
        """Gets the subject of this Result.  # noqa: E501


        :return: The subject of this Result.  # noqa: E501
        :rtype: list[XAny]
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this Result.


        :param subject: The subject of this Result.  # noqa: E501
        :type: list[XAny]
        """

        self._subject = subject

    @property
    def title(self):
        """Gets the title of this Result.  # noqa: E501


        :return: The title of this Result.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Result.


        :param title: The title of this Result.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def thumbnail(self):
        """Gets the thumbnail of this Result.  # noqa: E501


        :return: The thumbnail of this Result.  # noqa: E501
        :rtype: str
        """
        return self._thumbnail

    @thumbnail.setter
    def thumbnail(self, thumbnail):
        """Sets the thumbnail of this Result.


        :param thumbnail: The thumbnail of this Result.  # noqa: E501
        :type: str
        """

        self._thumbnail = thumbnail

    @property
    def type(self):
        """Gets the type of this Result.  # noqa: E501


        :return: The type of this Result.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Result.


        :param type: The type of this Result.  # noqa: E501
        :type: str
        """
        allowed_values = ["audio", "image", "video", "binary"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def updated_at(self):
        """Gets the updated_at of this Result.  # noqa: E501


        :return: The updated_at of this Result.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Result.


        :param updated_at: The updated_at of this Result.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this Result.  # noqa: E501


        :return: The id of this Result.  # noqa: E501
        :rtype: ObjectID
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Result.


        :param id: The id of this Result.  # noqa: E501
        :type: ObjectID
        """

        self._id = id

    @property
    def owner_id(self):
        """Gets the owner_id of this Result.  # noqa: E501


        :return: The owner_id of this Result.  # noqa: E501
        :rtype: ObjectID
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this Result.


        :param owner_id: The owner_id of this Result.  # noqa: E501
        :type: ObjectID
        """

        self._owner_id = owner_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Result):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    shado-python-client

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from shado_client.models.object_id import ObjectID  # noqa: F401,E501


class Membership(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'is_group_admin': 'bool',
        'created_at': 'datetime',
        'id': 'ObjectID',
        'owner_id': 'ObjectID',
        'invited_by': 'ObjectID',
        'group_id': 'ObjectID'
    }

    attribute_map = {
        'is_group_admin': 'isGroupAdmin',
        'created_at': 'createdAt',
        'id': 'id',
        'owner_id': 'ownerId',
        'invited_by': 'invitedBy',
        'group_id': 'groupId'
    }

    def __init__(self, is_group_admin=False, created_at=None, id=None, owner_id=None, invited_by=None, group_id=None):  # noqa: E501
        """Membership - a model defined in Swagger"""  # noqa: E501

        self._is_group_admin = None
        self._created_at = None
        self._id = None
        self._owner_id = None
        self._invited_by = None
        self._group_id = None
        self.discriminator = None

        if is_group_admin is not None:
            self.is_group_admin = is_group_admin
        if created_at is not None:
            self.created_at = created_at
        if id is not None:
            self.id = id
        if owner_id is not None:
            self.owner_id = owner_id
        if invited_by is not None:
            self.invited_by = invited_by
        if group_id is not None:
            self.group_id = group_id

    @property
    def is_group_admin(self):
        """Gets the is_group_admin of this Membership.  # noqa: E501


        :return: The is_group_admin of this Membership.  # noqa: E501
        :rtype: bool
        """
        return self._is_group_admin

    @is_group_admin.setter
    def is_group_admin(self, is_group_admin):
        """Sets the is_group_admin of this Membership.


        :param is_group_admin: The is_group_admin of this Membership.  # noqa: E501
        :type: bool
        """

        self._is_group_admin = is_group_admin

    @property
    def created_at(self):
        """Gets the created_at of this Membership.  # noqa: E501


        :return: The created_at of this Membership.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Membership.


        :param created_at: The created_at of this Membership.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def id(self):
        """Gets the id of this Membership.  # noqa: E501


        :return: The id of this Membership.  # noqa: E501
        :rtype: ObjectID
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Membership.


        :param id: The id of this Membership.  # noqa: E501
        :type: ObjectID
        """

        self._id = id

    @property
    def owner_id(self):
        """Gets the owner_id of this Membership.  # noqa: E501


        :return: The owner_id of this Membership.  # noqa: E501
        :rtype: ObjectID
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this Membership.


        :param owner_id: The owner_id of this Membership.  # noqa: E501
        :type: ObjectID
        """

        self._owner_id = owner_id

    @property
    def invited_by(self):
        """Gets the invited_by of this Membership.  # noqa: E501


        :return: The invited_by of this Membership.  # noqa: E501
        :rtype: ObjectID
        """
        return self._invited_by

    @invited_by.setter
    def invited_by(self, invited_by):
        """Sets the invited_by of this Membership.


        :param invited_by: The invited_by of this Membership.  # noqa: E501
        :type: ObjectID
        """

        self._invited_by = invited_by

    @property
    def group_id(self):
        """Gets the group_id of this Membership.  # noqa: E501


        :return: The group_id of this Membership.  # noqa: E501
        :rtype: ObjectID
        """
        return self._group_id

    @group_id.setter
    def group_id(self, group_id):
        """Sets the group_id of this Membership.


        :param group_id: The group_id of this Membership.  # noqa: E501
        :type: ObjectID
        """

        self._group_id = group_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Membership):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    shado-python-client

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from shado_client.models.object_id import ObjectID  # noqa: F401,E501


class Account(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_at': 'datetime',
        'is_admin': 'bool',
        'disabled': 'bool',
        'first_name': 'str',
        'last_name': 'str',
        'username': 'str',
        'realm': 'str',
        'email': 'str',
        'email_verified': 'bool',
        'id': 'ObjectID'
    }

    attribute_map = {
        'created_at': 'createdAt',
        'is_admin': 'isAdmin',
        'disabled': 'disabled',
        'first_name': 'firstName',
        'last_name': 'lastName',
        'username': 'username',
        'realm': 'realm',
        'email': 'email',
        'email_verified': 'emailVerified',
        'id': 'id'
    }

    def __init__(self, created_at=None, is_admin=False, disabled=False, first_name=None, last_name=None, username=None, realm=None, email=None, email_verified=None, id=None):  # noqa: E501
        """Account - a model defined in Swagger"""  # noqa: E501

        self._created_at = None
        self._is_admin = None
        self._disabled = None
        self._first_name = None
        self._last_name = None
        self._username = None
        self._realm = None
        self._email = None
        self._email_verified = None
        self._id = None
        self.discriminator = None

        if created_at is not None:
            self.created_at = created_at
        if is_admin is not None:
            self.is_admin = is_admin
        if disabled is not None:
            self.disabled = disabled
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        self.username = username
        if realm is not None:
            self.realm = realm
        self.email = email
        if email_verified is not None:
            self.email_verified = email_verified
        if id is not None:
            self.id = id

    @property
    def created_at(self):
        """Gets the created_at of this Account.  # noqa: E501


        :return: The created_at of this Account.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Account.


        :param created_at: The created_at of this Account.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def is_admin(self):
        """Gets the is_admin of this Account.  # noqa: E501


        :return: The is_admin of this Account.  # noqa: E501
        :rtype: bool
        """
        return self._is_admin

    @is_admin.setter
    def is_admin(self, is_admin):
        """Sets the is_admin of this Account.


        :param is_admin: The is_admin of this Account.  # noqa: E501
        :type: bool
        """

        self._is_admin = is_admin

    @property
    def disabled(self):
        """Gets the disabled of this Account.  # noqa: E501


        :return: The disabled of this Account.  # noqa: E501
        :rtype: bool
        """
        return self._disabled

    @disabled.setter
    def disabled(self, disabled):
        """Sets the disabled of this Account.


        :param disabled: The disabled of this Account.  # noqa: E501
        :type: bool
        """

        self._disabled = disabled

    @property
    def first_name(self):
        """Gets the first_name of this Account.  # noqa: E501


        :return: The first_name of this Account.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this Account.


        :param first_name: The first_name of this Account.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this Account.  # noqa: E501


        :return: The last_name of this Account.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this Account.


        :param last_name: The last_name of this Account.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def username(self):
        """Gets the username of this Account.  # noqa: E501


        :return: The username of this Account.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this Account.


        :param username: The username of this Account.  # noqa: E501
        :type: str
        """
        if username is None:
            raise ValueError("Invalid value for `username`, must not be `None`")  # noqa: E501

        self._username = username

    @property
    def realm(self):
        """Gets the realm of this Account.  # noqa: E501


        :return: The realm of this Account.  # noqa: E501
        :rtype: str
        """
        return self._realm

    @realm.setter
    def realm(self, realm):
        """Sets the realm of this Account.


        :param realm: The realm of this Account.  # noqa: E501
        :type: str
        """

        self._realm = realm

    @property
    def email(self):
        """Gets the email of this Account.  # noqa: E501


        :return: The email of this Account.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this Account.


        :param email: The email of this Account.  # noqa: E501
        :type: str
        """
        if email is None:
            raise ValueError("Invalid value for `email`, must not be `None`")  # noqa: E501

        self._email = email

    @property
    def email_verified(self):
        """Gets the email_verified of this Account.  # noqa: E501


        :return: The email_verified of this Account.  # noqa: E501
        :rtype: bool
        """
        return self._email_verified

    @email_verified.setter
    def email_verified(self, email_verified):
        """Sets the email_verified of this Account.


        :param email_verified: The email_verified of this Account.  # noqa: E501
        :type: bool
        """

        self._email_verified = email_verified

    @property
    def id(self):
        """Gets the id of this Account.  # noqa: E501


        :return: The id of this Account.  # noqa: E501
        :rtype: ObjectID
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Account.


        :param id: The id of this Account.  # noqa: E501
        :type: ObjectID
        """

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Account):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    shado-python-client

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from shado_client.models.object_id import ObjectID  # noqa: F401,E501


class Sharing(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_at': 'datetime',
        'id': 'ObjectID',
        'owner_id': 'ObjectID',
        'item_id': 'ObjectID',
        'group_id': 'ObjectID',
        'result_id': 'ObjectID'
    }

    attribute_map = {
        'created_at': 'createdAt',
        'id': 'id',
        'owner_id': 'ownerId',
        'item_id': 'itemId',
        'group_id': 'groupId',
        'result_id': 'resultId'
    }

    def __init__(self, created_at=None, id=None, owner_id=None, item_id=None, group_id=None, result_id=None):  # noqa: E501
        """Sharing - a model defined in Swagger"""  # noqa: E501

        self._created_at = None
        self._id = None
        self._owner_id = None
        self._item_id = None
        self._group_id = None
        self._result_id = None
        self.discriminator = None

        if created_at is not None:
            self.created_at = created_at
        if id is not None:
            self.id = id
        if owner_id is not None:
            self.owner_id = owner_id
        if item_id is not None:
            self.item_id = item_id
        if group_id is not None:
            self.group_id = group_id
        if result_id is not None:
            self.result_id = result_id

    @property
    def created_at(self):
        """Gets the created_at of this Sharing.  # noqa: E501


        :return: The created_at of this Sharing.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Sharing.


        :param created_at: The created_at of this Sharing.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def id(self):
        """Gets the id of this Sharing.  # noqa: E501


        :return: The id of this Sharing.  # noqa: E501
        :rtype: ObjectID
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Sharing.


        :param id: The id of this Sharing.  # noqa: E501
        :type: ObjectID
        """

        self._id = id

    @property
    def owner_id(self):
        """Gets the owner_id of this Sharing.  # noqa: E501


        :return: The owner_id of this Sharing.  # noqa: E501
        :rtype: ObjectID
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this Sharing.


        :param owner_id: The owner_id of this Sharing.  # noqa: E501
        :type: ObjectID
        """

        self._owner_id = owner_id

    @property
    def item_id(self):
        """Gets the item_id of this Sharing.  # noqa: E501


        :return: The item_id of this Sharing.  # noqa: E501
        :rtype: ObjectID
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """Sets the item_id of this Sharing.


        :param item_id: The item_id of this Sharing.  # noqa: E501
        :type: ObjectID
        """

        self._item_id = item_id

    @property
    def group_id(self):
        """Gets the group_id of this Sharing.  # noqa: E501


        :return: The group_id of this Sharing.  # noqa: E501
        :rtype: ObjectID
        """
        return self._group_id

    @group_id.setter
    def group_id(self, group_id):
        """Sets the group_id of this Sharing.


        :param group_id: The group_id of this Sharing.  # noqa: E501
        :type: ObjectID
        """

        self._group_id = group_id

    @property
    def result_id(self):
        """Gets the result_id of this Sharing.  # noqa: E501


        :return: The result_id of this Sharing.  # noqa: E501
        :rtype: ObjectID
        """
        return self._result_id

    @result_id.setter
    def result_id(self, result_id):
        """Sets the result_id of this Sharing.


        :param result_id: The result_id of this Sharing.  # noqa: E501
        :type: ObjectID
        """

        self._result_id = result_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Sharing):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    shado-python-client

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from shado_client.models.object_id import ObjectID  # noqa: F401,E501


class Plugin(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'type': 'str',
        'description': 'str',
        'created_at': 'datetime',
        'updated_at': 'datetime',
        'resource_created_at': 'datetime',
        'uri': 'str',
        'status': 'str',
        'gui': 'object',
        'id': 'ObjectID',
        'owner_id': 'ObjectID'
    }

    attribute_map = {
        'name': 'name',
        'type': 'type',
        'description': 'description',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt',
        'resource_created_at': 'resourceCreatedAt',
        'uri': 'uri',
        'status': 'status',
        'gui': 'gui',
        'id': 'id',
        'owner_id': 'ownerId'
    }

    def __init__(self, name=None, type=None, description=None, created_at=None, updated_at=None, resource_created_at=None, uri=None, status='uploaded', gui=None, id=None, owner_id=None):  # noqa: E501
        """Plugin - a model defined in Swagger"""  # noqa: E501

        self._name = None
        self._type = None
        self._description = None
        self._created_at = None
        self._updated_at = None
        self._resource_created_at = None
        self._uri = None
        self._status = None
        self._gui = None
        self._id = None
        self._owner_id = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if type is not None:
            self.type = type
        if description is not None:
            self.description = description
        if created_at is not None:
            self.created_at = created_at
        if updated_at is not None:
            self.updated_at = updated_at
        if resource_created_at is not None:
            self.resource_created_at = resource_created_at
        if uri is not None:
            self.uri = uri
        if status is not None:
            self.status = status
        if gui is not None:
            self.gui = gui
        if id is not None:
            self.id = id
        if owner_id is not None:
            self.owner_id = owner_id

    @property
    def name(self):
        """Gets the name of this Plugin.  # noqa: E501


        :return: The name of this Plugin.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Plugin.


        :param name: The name of this Plugin.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def type(self):
        """Gets the type of this Plugin.  # noqa: E501


        :return: The type of this Plugin.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Plugin.


        :param type: The type of this Plugin.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def description(self):
        """Gets the description of this Plugin.  # noqa: E501


        :return: The description of this Plugin.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Plugin.


        :param description: The description of this Plugin.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def created_at(self):
        """Gets the created_at of this Plugin.  # noqa: E501


        :return: The created_at of this Plugin.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Plugin.


        :param created_at: The created_at of this Plugin.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this Plugin.  # noqa: E501


        :return: The updated_at of this Plugin.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this Plugin.


        :param updated_at: The updated_at of this Plugin.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    @property
    def resource_created_at(self):
        """Gets the resource_created_at of this Plugin.  # noqa: E501


        :return: The resource_created_at of this Plugin.  # noqa: E501
        :rtype: datetime
        """
        return self._resource_created_at

    @resource_created_at.setter
    def resource_created_at(self, resource_created_at):
        """Sets the resource_created_at of this Plugin.


        :param resource_created_at: The resource_created_at of this Plugin.  # noqa: E501
        :type: datetime
        """

        self._resource_created_at = resource_created_at

    @property
    def uri(self):
        """Gets the uri of this Plugin.  # noqa: E501


        :return: The uri of this Plugin.  # noqa: E501
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """Sets the uri of this Plugin.


        :param uri: The uri of this Plugin.  # noqa: E501
        :type: str
        """

        self._uri = uri

    @property
    def status(self):
        """Gets the status of this Plugin.  # noqa: E501


        :return: The status of this Plugin.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Plugin.


        :param status: The status of this Plugin.  # noqa: E501
        :type: str
        """
        allowed_values = ["uploaded", "installing", "ready"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def gui(self):
        """Gets the gui of this Plugin.  # noqa: E501


        :return: The gui of this Plugin.  # noqa: E501
        :rtype: object
        """
        return self._gui

    @gui.setter
    def gui(self, gui):
        """Sets the gui of this Plugin.


        :param gui: The gui of this Plugin.  # noqa: E501
        :type: object
        """

        self._gui = gui

    @property
    def id(self):
        """Gets the id of this Plugin.  # noqa: E501


        :return: The id of this Plugin.  # noqa: E501
        :rtype: ObjectID
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Plugin.


        :param id: The id of this Plugin.  # noqa: E501
        :type: ObjectID
        """

        self._id = id

    @property
    def owner_id(self):
        """Gets the owner_id of this Plugin.  # noqa: E501


        :return: The owner_id of this Plugin.  # noqa: E501
        :rtype: ObjectID
        """
        return self._owner_id

    @owner_id.setter
    def owner_id(self, owner_id):
        """Sets the owner_id of this Plugin.


        :param owner_id: The owner_id of this Plugin.  # noqa: E501
        :type: ObjectID
        """

        self._owner_id = owner_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Plugin):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    shado-python-client

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from shado_client.api_client import ApiClient


class PluginInstanceApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def plugin_instance_by_account(self, **kwargs):  # noqa: E501
        """Retrieve all PluginInstances for the given Account.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.plugin_instance_by_account(async=True)
        >>> result = thread.get()

        :param async bool
        :param str filter:
        :return: list[XAny]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.plugin_instance_by_account_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.plugin_instance_by_account_with_http_info(**kwargs)  # noqa: E501
            return data

    def plugin_instance_by_account_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieve all PluginInstances for the given Account.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.plugin_instance_by_account_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :param str filter:
        :return: list[XAny]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['filter']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method plugin_instance_by_account" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter' in params:
            query_params.append(('filter', params['filter']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/PluginInstances/byAccount', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[XAny]',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def plugin_instance_create(self, **kwargs):  # noqa: E501
        """Create a new instance of the model and persist it into the data source.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.plugin_instance_create(async=True)
        >>> result = thread.get()

        :param async bool
        :param PluginInstance data: Model instance data
        :return: PluginInstance
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.plugin_instance_create_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.plugin_instance_create_with_http_info(**kwargs)  # noqa: E501
            return data

    def plugin_instance_create_with_http_info(self, **kwargs):  # noqa: E501
        """Create a new instance of the model and persist it into the data source.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.plugin_instance_create_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :param PluginInstance data: Model instance data
        :return: PluginInstance
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['data']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method plugin_instance_create" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'data' in params:
            body_params = params['data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/PluginInstances', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PluginInstance',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def plugin_instance_create_change_stream_get_plugin_instances_change_stream(self, **kwargs):  # noqa: E501
        """Create a change stream.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.plugin_instance_create_change_stream_get_plugin_instances_change_stream(async=True)
        >>> result = thread.get()

        :param async bool
        :param str options:
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.plugin_instance_create_change_stream_get_plugin_instances_change_stream_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.plugin_instance_create_change_stream_get_plugin_instances_change_stream_with_http_info(**kwargs)  # noqa: E501
            return data

    def plugin_instance_create_change_stream_get_plugin_instances_change_stream_with_http_info(self, **kwargs):  # noqa: E501
        """Create a change stream.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.plugin_instance_create_change_stream_get_plugin_instances_change_stream_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :param str options:
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['options']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method plugin_instance_create_change_stream_get_plugin_instances_change_stream" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'options' in params:
            query_params.append(('options', params['options']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/PluginInstances/change-stream', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='file',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def plugin_instance_create_change_stream_post_plugin_instances_change_stream(self, **kwargs):  # noqa: E501
        """Create a change stream.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.plugin_instance_create_change_stream_post_plugin_instances_change_stream(async=True)
        >>> result = thread.get()

        :param async bool
        :param str options:
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.plugin_instance_create_change_stream_post_plugin_instances_change_stream_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.plugin_instance_create_change_stream_post_plugin_instances_change_stream_with_http_info(**kwargs)  # noqa: E501
            return data

    def plugin_instance_create_change_stream_post_plugin_instances_change_stream_with_http_info(self, **kwargs):  # noqa: E501
        """Create a change stream.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.plugin_instance_create_change_stream_post_plugin_instances_change_stream_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :param str options:
        :return: file
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['options']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method plugin_instance_create_change_stream_post_plugin_instances_change_stream" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if 'options' in params:
            form_params.append(('options', params['options']))  # noqa: E501

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/PluginInstances/change-stream', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='file',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def plugin_instance_delete_by_id(self, id, **kwargs):  # noqa: E501
        """Delete a model instance by {{id}} from the data source.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.plugin_instance_delete_by_id(id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str id: Model id (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.plugin_instance_delete_by_id_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.plugin_instance_delete_by_id_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def plugin_instance_delete_by_id_with_http_info(self, id, **kwargs):  # noqa: E501
        """Delete a model instance by {{id}} from the data source.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.plugin_instance_delete_by_id_with_http_info(id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str id: Model id (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method plugin_instance_delete_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `plugin_instance_delete_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/PluginInstances/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def plugin_instance_find(self, **kwargs):  # noqa: E501
        """Find all instances of the model matched by filter from the data source.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.plugin_instance_find(async=True)
        >>> result = thread.get()

        :param async bool
        :param str filter: Filter defining fields, where, include, order, offset, and limit - must be a JSON-encoded string ({\"something\":\"value\"})
        :return: list[PluginInstance]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.plugin_instance_find_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.plugin_instance_find_with_http_info(**kwargs)  # noqa: E501
            return data

    def plugin_instance_find_with_http_info(self, **kwargs):  # noqa: E501
        """Find all instances of the model matched by filter from the data source.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.plugin_instance_find_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :param str filter: Filter defining fields, where, include, order, offset, and limit - must be a JSON-encoded string ({\"something\":\"value\"})
        :return: list[PluginInstance]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['filter']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method plugin_instance_find" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter' in params:
            query_params.append(('filter', params['filter']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/PluginInstances', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[PluginInstance]',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def plugin_instance_find_by_id(self, id, **kwargs):  # noqa: E501
        """Find a model instance by {{id}} from the data source.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.plugin_instance_find_by_id(id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str id: Model id (required)
        :param str filter: Filter defining fields and include - must be a JSON-encoded string ({\"something\":\"value\"})
        :return: PluginInstance
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.plugin_instance_find_by_id_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.plugin_instance_find_by_id_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def plugin_instance_find_by_id_with_http_info(self, id, **kwargs):  # noqa: E501
        """Find a model instance by {{id}} from the data source.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.plugin_instance_find_by_id_with_http_info(id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str id: Model id (required)
        :param str filter: Filter defining fields and include - must be a JSON-encoded string ({\"something\":\"value\"})
        :return: PluginInstance
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'filter']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method plugin_instance_find_by_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `plugin_instance_find_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'filter' in params:
            query_params.append(('filter', params['filter']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/PluginInstances/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PluginInstance',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def plugin_instance_prototype_get_plugin(self, id, **kwargs):  # noqa: E501
        """Fetches belongsTo relation plugin.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.plugin_instance_prototype_get_plugin(id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str id: PluginInstance id (required)
        :param bool refresh:
        :return: Plugin
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.plugin_instance_prototype_get_plugin_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.plugin_instance_prototype_get_plugin_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def plugin_instance_prototype_get_plugin_with_http_info(self, id, **kwargs):  # noqa: E501
        """Fetches belongsTo relation plugin.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.plugin_instance_prototype_get_plugin_with_http_info(id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str id: PluginInstance id (required)
        :param bool refresh:
        :return: Plugin
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'refresh']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method plugin_instance_prototype_get_plugin" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `plugin_instance_prototype_get_plugin`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'refresh' in params:
            query_params.append(('refresh', params['refresh']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/PluginInstances/{id}/plugin', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Plugin',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def plugin_instance_replace_by_id_post_plugin_instancesid_replace(self, id, **kwargs):  # noqa: E501
        """Replace attributes for a model instance and persist it into the data source.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.plugin_instance_replace_by_id_post_plugin_instancesid_replace(id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str id: Model id (required)
        :param PluginInstance data: Model instance data
        :return: PluginInstance
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.plugin_instance_replace_by_id_post_plugin_instancesid_replace_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.plugin_instance_replace_by_id_post_plugin_instancesid_replace_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def plugin_instance_replace_by_id_post_plugin_instancesid_replace_with_http_info(self, id, **kwargs):  # noqa: E501
        """Replace attributes for a model instance and persist it into the data source.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.plugin_instance_replace_by_id_post_plugin_instancesid_replace_with_http_info(id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str id: Model id (required)
        :param PluginInstance data: Model instance data
        :return: PluginInstance
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'data']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method plugin_instance_replace_by_id_post_plugin_instancesid_replace" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `plugin_instance_replace_by_id_post_plugin_instancesid_replace`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'data' in params:
            body_params = params['data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/PluginInstances/{id}/replace', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PluginInstance',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def plugin_instance_replace_by_id_put_plugin_instancesid(self, id, **kwargs):  # noqa: E501
        """Replace attributes for a model instance and persist it into the data source.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.plugin_instance_replace_by_id_put_plugin_instancesid(id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str id: Model id (required)
        :param PluginInstance data: Model instance data
        :return: PluginInstance
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.plugin_instance_replace_by_id_put_plugin_instancesid_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.plugin_instance_replace_by_id_put_plugin_instancesid_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def plugin_instance_replace_by_id_put_plugin_instancesid_with_http_info(self, id, **kwargs):  # noqa: E501
        """Replace attributes for a model instance and persist it into the data source.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.plugin_instance_replace_by_id_put_plugin_instancesid_with_http_info(id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str id: Model id (required)
        :param PluginInstance data: Model instance data
        :return: PluginInstance
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'data']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method plugin_instance_replace_by_id_put_plugin_instancesid" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `plugin_instance_replace_by_id_put_plugin_instancesid`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'data' in params:
            body_params = params['data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/PluginInstances/{id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PluginInstance',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def plugin_instance_update_all(self, **kwargs):  # noqa: E501
        """Update instances of the model matched by {{where}} from the data source.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.plugin_instance_update_all(async=True)
        >>> result = thread.get()

        :param async bool
        :param str where: Criteria to match model instances
        :param PluginInstance data: An object of model property name/value pairs
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.plugin_instance_update_all_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.plugin_instance_update_all_with_http_info(**kwargs)  # noqa: E501
            return data

    def plugin_instance_update_all_with_http_info(self, **kwargs):  # noqa: E501
        """Update instances of the model matched by {{where}} from the data source.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.plugin_instance_update_all_with_http_info(async=True)
        >>> result = thread.get()

        :param async bool
        :param str where: Criteria to match model instances
        :param PluginInstance data: An object of model property name/value pairs
        :return: InlineResponse200
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['where', 'data']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method plugin_instance_update_all" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'where' in params:
            query_params.append(('where', params['where']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'data' in params:
            body_params = params['data']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/PluginInstances/update', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='InlineResponse200',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def plugin_instance_update_field(self, id, **kwargs):  # noqa: E501
        """plugin_instance_update_field  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.plugin_instance_update_field(id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str id: (required)
        :param object attributes:
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async'):
            return self.plugin_instance_update_field_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.plugin_instance_update_field_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def plugin_instance_update_field_with_http_info(self, id, **kwargs):  # noqa: E501
        """plugin_instance_update_field  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async=True
        >>> thread = api.plugin_instance_update_field_with_http_info(id, async=True)
        >>> result = thread.get()

        :param async bool
        :param str id: (required)
        :param object attributes:
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'attributes']  # noqa: E501
        all_params.append('async')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method plugin_instance_update_field" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `plugin_instance_update_field`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'attributes' in params:
            body_params = params['attributes']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/xml', 'text/xml', 'application/javascript', 'text/javascript'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'application/x-www-form-urlencoded', 'application/xml', 'text/xml'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/PluginInstances/{id}/updateField', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async=params.get('async'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
